@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Log::Dispatchouli;
 BEGIN {
-  $Log::Dispatchouli::VERSION = '2.001';
+  $Log::Dispatchouli::VERSION = '2.002';
 }
 # ABSTRACT: a simple wrapper around Log::Dispatch
 
@@ -44,7 +44,7 @@ sub new {
   if ($arg->{to_file}) {
     require Log::Dispatch::File;
     my $log_file = File::Spec->catfile(
-      ($ENV{DISPATCHOULI_PATH} || File::Spec->tmpdir),
+      ($self->env_value('PATH') || File::Spec->tmpdir),
       sprintf('%s.%04u%02u%02u',
         $ident,
         ((localtime)[5] + 1900),
@@ -68,7 +68,7 @@ sub new {
     );
   }
 
-  if ($arg->{facility} and not $ENV{DISPATCHOULI_NOSYSLOG}) {
+  if ($arg->{facility} and not $self->env_value('NOSYSLOG')) {
     require Log::Dispatch::Syslog;
     $log->add(
       Log::Dispatch::Syslog->new(
@@ -120,7 +120,7 @@ sub new {
 
   $self->{debug}  = exists $arg->{debug}
                   ? ($arg->{debug} ? 1 : 0)
-                  : ($ENV{DISPATCHOULI_DEBUG} ? 1 : 0);
+                  : ($self->env_value('DEBUG') ? 1 : 0);
 
   $self->{fail_fatal} = exists $arg->{fail_fatal} ? $arg->{fail_fatal} : 1;
 
@@ -233,6 +233,23 @@ sub ident { $_[0]{ident} }
 sub string_flogger { 'String::Flogger' }
 
 
+sub env_prefix { return; }
+
+
+sub env_value {
+  my ($self, $suffix) = @_;
+
+  my @path = grep { defined } ($self->env_prefix, 'DISPATCHOULI');
+
+  for my $prefix (@path) {
+    my $name = join q{_}, $prefix, $suffix;
+    return $ENV{ $name } if defined $ENV{ $name };
+  }
+
+  return;
+}
+
+
 sub new_tester {
   my ($class, $arg) = @_;
   $arg ||= {};
@@ -313,7 +330,7 @@ Log::Dispatchouli - a simple wrapper around Log::Dispatch
 
 =head1 VERSION
 
-version 2.001
+version 2.002
 
 =head1 SYNOPSIS
 
@@ -521,6 +538,25 @@ settings, which accumulate.  So:
 This method returns the thing on which F<flog> will be called to format log
 messages.  By default, it just returns C<String::Flogger>
 
+=head2 env_prefix
+
+This method should return a string used as a prefix to find environment
+variables that affect the logger's behavior.  For example, if this method
+returns C<XYZZY> then when checking the environment for a default value for the
+C<debug> parameter, Log::Dispatchouli will first check C<XYZZY_DEBUG>, then
+C<DISPATCHOULI_DEBUG>.
+
+By default, this method returns C<()>, which means no extra environment
+variable is checked.
+
+=head2 env_value
+
+  my $value = $logger->env_value('DEBUG');
+
+This method returns the value for the environment variable suffix given.  For
+example, the example given, calling with C<DEBUG> will check
+C<DISPATCHOULI_DEBUG>.
+
 =head1 METHODS FOR TESTING
 
 =head2 new_tester
